==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/documents/classes/workflow/WFTransitionFactory.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] ?: array()) + array("i" . "d" => base64_decode("a" . "W" . "Q" . "="), "_08aa8c963" . "1295656e6b" . "3f403b6dcc" . "eb3" => base64_decode("d2Zfa" . "WQ9aW" . "50Ond" . "mX2lk"), "_b963770c44230ebe4fec" . "8fa56a7164c7" => base64_decode("ZnJvbV9zdGF0dXMgP" . "SBpbnQ6c3RhdGVfaW" . "Q="), "_7d31eb61a" . "c33303230c" . "23102fdfd5" . "2c3" => base64_decode("Tm" . "9u" . "ZQ" . "=="));




class WFTransitionFactory
{
    
    
    
    
    
    
    
    public static function CreateInstance($_7225eff8b08a45e56a04943da5f8ef2b)
    {
        $_6d531f6dc9e331a0e9b18556f51742ea = null;
        switch ($_7225eff8b08a45e56a04943da5f8ef2b) {
            case WF_TRANSITION_NONE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionNone();
                break;
            case WF_TRANSITION_TIME_ELAPSE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionPeriod();
                break;
            case WF_TRANSITION_DATETIME:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionDatetime();
                break;
            case WF_TRANSITION_PERIOD:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionPeriod();
                break;
            case WF_TRANSITION_ALL_APPROVE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionAllApprove();
                break;
            case WF_TRANSITION_ONE_APPROVE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionOneApprove();
                break;
            default:
                return null;
                
                
        }
        $_6d531f6dc9e331a0e9b18556f51742ea->SetType($_7225eff8b08a45e56a04943da5f8ef2b);
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    public static function LoadInstance($id)
    {
        $_c4c0f15c5891a8ac349f1b56352500b5 = new WFTransition();
        if (!$_c4c0f15c5891a8ac349f1b56352500b5->Load($id)) {
            return false;
        }
        $_6d531f6dc9e331a0e9b18556f51742ea = WFTransitionFactory::CreateInstance($_c4c0f15c5891a8ac349f1b56352500b5->GetType());
        if (!$_6d531f6dc9e331a0e9b18556f51742ea) {
            return false;
        }
        if (!$_6d531f6dc9e331a0e9b18556f51742ea->Load($id)) {
            return false;
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    public static function GetAllInstancesByState($_226b051490848e9e1835697931696225)
    {
        global $db;
        if ($_226b051490848e9e1835697931696225 <= 0) {
            return array();
        }
        $_c4c0f15c5891a8ac349f1b56352500b5 = new WFTransition();
        $_714e1da7f6235557a4490c30b448e1ad = $_c4c0f15c5891a8ac349f1b56352500b5->GenerateSelect();
        $_714e1da7f6235557a4490c30b448e1ad->AddWhereAndClause($GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_b963770c44230ebe4fec8fa56a71" . "64c7"], $_226b051490848e9e1835697931696225);
        $_7f5aa4e96d4b415a86ed72ebff677cbe = $_714e1da7f6235557a4490c30b448e1ad->GetQuery();
        $_1f24efd4735b7a11b391147435e7d35d = $db->query($_7f5aa4e96d4b415a86ed72ebff677cbe);
        $_6d531f6dc9e331a0e9b18556f51742ea = array();
        while (($_b8cfc2e06d9d1fec1893ea4a054002bf = $_1f24efd4735b7a11b391147435e7d35d->fetchArray()) != null) {
            $_07e41711580f2279161feffa9f744876 = WFTransitionFactory::LoadInstance($_b8cfc2e06d9d1fec1893ea4a054002bf[$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["i" . "d"]]);
            if ($_07e41711580f2279161feffa9f744876) {
                $_6d531f6dc9e331a0e9b18556f51742ea[] = $_07e41711580f2279161feffa9f744876;
            }
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    public static function GetAllInstancesByWF($_eb57e3a45673c8e851b42c4eee3742ea)
    {
        global $db;
        if ($_eb57e3a45673c8e851b42c4eee3742ea <= 0) {
            return array();
        }
        $_c4c0f15c5891a8ac349f1b56352500b5 = new WFTransition();
        $_714e1da7f6235557a4490c30b448e1ad = $_c4c0f15c5891a8ac349f1b56352500b5->GenerateSelect();
        $_714e1da7f6235557a4490c30b448e1ad->AddWhereAndClause($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_08aa8c9631295656e" . "6b3f403b6dcceb3"], $_eb57e3a45673c8e851b42c4eee3742ea);
        $_7f5aa4e96d4b415a86ed72ebff677cbe = $_714e1da7f6235557a4490c30b448e1ad->GetQuery();
        $_1f24efd4735b7a11b391147435e7d35d = $db->query($_7f5aa4e96d4b415a86ed72ebff677cbe);
        $_6d531f6dc9e331a0e9b18556f51742ea = array();
        while (($_b8cfc2e06d9d1fec1893ea4a054002bf = $_1f24efd4735b7a11b391147435e7d35d->fetchArray()) != null) {
            $_07e41711580f2279161feffa9f744876 = WFTransitionFactory::LoadInstance($_b8cfc2e06d9d1fec1893ea4a054002bf[$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["i" . "d"]]);
            if ($_07e41711580f2279161feffa9f744876) {
                $_6d531f6dc9e331a0e9b18556f51742ea[] = $_07e41711580f2279161feffa9f744876;
            }
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    public static function GetAllTitles()
    {
        $_6d531f6dc9e331a0e9b18556f51742ea = array();
        $_6d531f6dc9e331a0e9b18556f51742ea[WF_TRANSITION_NONE] = $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_7d31eb61a" . "c33303230c" . "23102fdfd5" . "2c3"];
        
        
        
        
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/documents/classes/workflow/WFTransitionFactory.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"] ?: array()) + array("_7d31eb61ac33303230c23102fdfd" . "52c3" => base64_decode("Tm" . "9u" . "ZQ" . "=="), "i" . "d" => base64_decode("a" . "W" . "Q" . "="), "_b963770" . "c44230eb" . "e4fec8fa" . "56a7164c" . "7" => base64_decode("ZnJvbV9zdGF0dXMgPSBpbn" . "Q6c3RhdGVfaWQ="), "_08aa8c96" . "31295656e" . "6b3f403b6" . "dcceb3" => base64_decode("d2Zfa" . "WQ9aW" . "50Ond" . "mX2lk"));




class WFTransitionFactory
{
    
    
    
    
    
    
    
    public static function CreateInstance($_7225eff8b08a45e56a04943da5f8ef2b)
    {
        $_6d531f6dc9e331a0e9b18556f51742ea = null;
        switch ($_7225eff8b08a45e56a04943da5f8ef2b) {
            case WF_TRANSITION_NONE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionNone();
                break;
            case WF_TRANSITION_TIME_ELAPSE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionPeriod();
                break;
            case WF_TRANSITION_DATETIME:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionDatetime();
                break;
            case WF_TRANSITION_PERIOD:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionPeriod();
                break;
            case WF_TRANSITION_ALL_APPROVE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionAllApprove();
                break;
            case WF_TRANSITION_ONE_APPROVE:
                $_6d531f6dc9e331a0e9b18556f51742ea = new WFTransitionOneApprove();
                break;
            default:
                return null;
                
                
        }
        $_6d531f6dc9e331a0e9b18556f51742ea->SetType($_7225eff8b08a45e56a04943da5f8ef2b);
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    public static function LoadInstance($id)
    {
        $_c4c0f15c5891a8ac349f1b56352500b5 = new WFTransition();
        if (!$_c4c0f15c5891a8ac349f1b56352500b5->Load($id)) {
            return false;
        }
        $_6d531f6dc9e331a0e9b18556f51742ea = WFTransitionFactory::CreateInstance($_c4c0f15c5891a8ac349f1b56352500b5->GetType());
        if (!$_6d531f6dc9e331a0e9b18556f51742ea) {
            return false;
        }
        if (!$_6d531f6dc9e331a0e9b18556f51742ea->Load($id)) {
            return false;
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    public static function GetAllInstancesByState($_226b051490848e9e1835697931696225)
    {
        global $db;
        if ($_226b051490848e9e1835697931696225 <= 0) {
            return array();
        }
        $_c4c0f15c5891a8ac349f1b56352500b5 = new WFTransition();
        $_714e1da7f6235557a4490c30b448e1ad = $_c4c0f15c5891a8ac349f1b56352500b5->GenerateSelect();
        $_714e1da7f6235557a4490c30b448e1ad->AddWhereAndClause($GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_b963770c44230ebe4fec" . "8fa56a7164c7"], $_226b051490848e9e1835697931696225);
        $_7f5aa4e96d4b415a86ed72ebff677cbe = $_714e1da7f6235557a4490c30b448e1ad->GetQuery();
        $_1f24efd4735b7a11b391147435e7d35d = $db->query($_7f5aa4e96d4b415a86ed72ebff677cbe);
        $_6d531f6dc9e331a0e9b18556f51742ea = array();
        while (($_b8cfc2e06d9d1fec1893ea4a054002bf = $_1f24efd4735b7a11b391147435e7d35d->fetchArray()) != null) {
            $_07e41711580f2279161feffa9f744876 = WFTransitionFactory::LoadInstance($_b8cfc2e06d9d1fec1893ea4a054002bf[$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["i" . "d"]]);
            if ($_07e41711580f2279161feffa9f744876) {
                $_6d531f6dc9e331a0e9b18556f51742ea[] = $_07e41711580f2279161feffa9f744876;
            }
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    public static function GetAllInstancesByWF($_eb57e3a45673c8e851b42c4eee3742ea)
    {
        global $db;
        if ($_eb57e3a45673c8e851b42c4eee3742ea <= 0) {
            return array();
        }
        $_c4c0f15c5891a8ac349f1b56352500b5 = new WFTransition();
        $_714e1da7f6235557a4490c30b448e1ad = $_c4c0f15c5891a8ac349f1b56352500b5->GenerateSelect();
        $_714e1da7f6235557a4490c30b448e1ad->AddWhereAndClause($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_08aa8c9631295656e6b3f403b6dcc" . "eb3"], $_eb57e3a45673c8e851b42c4eee3742ea);
        $_7f5aa4e96d4b415a86ed72ebff677cbe = $_714e1da7f6235557a4490c30b448e1ad->GetQuery();
        $_1f24efd4735b7a11b391147435e7d35d = $db->query($_7f5aa4e96d4b415a86ed72ebff677cbe);
        $_6d531f6dc9e331a0e9b18556f51742ea = array();
        while (($_b8cfc2e06d9d1fec1893ea4a054002bf = $_1f24efd4735b7a11b391147435e7d35d->fetchArray()) != null) {
            $_07e41711580f2279161feffa9f744876 = WFTransitionFactory::LoadInstance($_b8cfc2e06d9d1fec1893ea4a054002bf[$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["i" . "d"]]);
            if ($_07e41711580f2279161feffa9f744876) {
                $_6d531f6dc9e331a0e9b18556f51742ea[] = $_07e41711580f2279161feffa9f744876;
            }
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    public static function GetAllTitles()
    {
        $_6d531f6dc9e331a0e9b18556f51742ea = array();
        $_6d531f6dc9e331a0e9b18556f51742ea[WF_TRANSITION_NONE] = $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_7d31eb61ac3330" . "3230c23102fdfd5" . "2c3"];
        
        
        
        
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
}
